@@ -80,7 +80,7 @@ tdir=$(mktemp -d)
 mkdir $tdir/$distribution
 
 # Remove / Uncomment some macros po4a cannot handle
-# The last two can be removed, if mkpasswd (Debian BTS #1036908) and gawk (reported upstream) are fixed (or Debian #1036826)
+# The last two can be removed, if mkpasswd (Debian BTS #1036908) and gawk (fixed upstream) are fixed (or Debian #1036826)
 cat $master | sed "s/^.ft C$/^\".ft C$/" | sed "s/^.ft P$/^\".ft P$/" | sed "s/\\\\fb/\\fB/" | sed "s/^\.BI \(\\\\.*\)\"\\\\c$/.BI \1\"/" | sed "s/^\.BR \(\\\\.*\)\"\\\\c$/.BI \1\"/" > $tdir/$distribution/$manname
 
 # Actual translation
@@ -89,7 +89,7 @@ if [ -f noaddendum ]; then
 	-f man \
 	--option groff_code=verbatim \
 	--option generated \
-	--option untranslated="}1,Ds,zY,zZ,Ee,ES,dT,rstReportMargin,INDENT,UNINDENT,UN,a.RE,\|" \
+	--option untranslated="}1,Ds,zY,zZ,Ee,ES,dT,FN,NE,NS,EX,EE,Id,rstReportMargin,INDENT,UNINDENT,UN,a.RE,\|" \
 	--option unknown_macros=untranslated \
 	-m "$tdir/$distribution/$manname" \
 	-M "utf-8" \
@@ -101,7 +101,7 @@ else
 	-f man \
 	--option groff_code=verbatim \
 	--option generated \
-	--option untranslated="}1,Ds,zY,zZ,Ee,ES,dT,rstReportMargin,INDENT,UNINDENT,UN,a.RE,\|" \
+	--option untranslated="}1,Ds,zY,zZ,Ee,ES,dT,NE,NS,EX,EE,Id,rstReportMargin,INDENT,UNINDENT,UN,a.RE,\|" \
 	--option unknown_macros=untranslated \
 	-m "$tdir/$distribution/$manname" \
 	-M "utf-8" \
