@@ -39,15 +39,16 @@ number_translators=$(echo "$translators" | wc -l)
 
 # Output of common header
 echo "PO4A-HEADER:mode=after;position=^\.(TH|Dt);beginboundary=FakePo4aBoundary" > "$addendum"
-echo >> "$addendum"
 
 # Special case for manpages which use mdoc syntax
 if [ $ismdoc ]; then
     # MDOC File
-    echo ".Sh ◈PEBO◈" >> "$addendum"
+    echo ".Pp" >> "$addendum"
+    echo ".Sh ПРЕВОД" >> "$addendum"
 else
     # Groff file
-    echo ".SH ◈PEBO◈" >> "$addendum"
+    echo ".PP" >> "$addendum"
+    echo ".SH ПРЕВОД" >> "$addendum"
 fi
 echo "Српски превод ове странице са приручником смо направили" >> "$addendum"
 
