@@ -45,21 +45,20 @@ tdir=$(mktemp -d)
 mkdir $tdir/$distribution
 
 # Remove / Uncomment some macros po4a cannot handle
-# The last two can be removed, if mkpasswd (Debian BTS #1036908) and gawk (reported upstream) are fixed (or Debian #1036826)
+# The last two can be removed, if mkpasswd (Debian BTS #1036908) and gawk (fixed upstream) are fixed (or Debian #1036826)
 cat $upstream_manpage | sed "s/^.ft C$/^\".ft C$/" | sed "s/^.ft P$/^\".ft P$/" | sed "s/\\\\fb/\\fB/" | sed "s/^\.BI \(\\\\.*\)\"\\\\c$/.BI \1\"/" | sed "s/^\.BR \(\\\\.*\)\"\\\\c$/.BI \1\"/" > $tdir/$distribution/$manpage
 
 po4a-updatepo -f man \
         --no-deprecation \
 	--option groff_code=verbatim \
 	--option generated \
-	--option untranslated="}1,Ds,zY,zZ,Ee,ES,dT,rstReportMargin,INDENT,UNINDENT,UN,a.RE,\|" \
+	--option untranslated="}1,Ds,zY,zZ,Ee,ES,dT,FN,NE,NS,EX,EE,Id,rstReportMargin,INDENT,UNINDENT,UN,a.RE,\|" \
 	--option unknown_macros=untranslated \
 	--master "$tdir/$distribution/$manpage" -M utf-8 \
 	-p $tdir/tmp.pot
 
 # Reduce the location lines from the full path and line number
-# to the name of the distribution
-cat $tdir/tmp.pot | sed -e "s,^#: /tmp/tmp\.[a-zA-Z0-9]*/\([^/]\+\)/.*,#: \1," |\
+cat $tdir/tmp.pot | sed -e "s,/tmp/\.private/[a-zA-Z0-9]*/tmp\.,/tmp/tmp.," | sed -e "s,^#: /tmp/tmp\.[a-zA-Z0-9]*/\([^/]\+\)/.*,#: \1," |\
 	# Ensure the correct encoding is set
 	sed -e "s/^\"Content-Type: text\/plain; charset=CHARSET\\\\n\"$/\"Content-Type: text\/plain; charset=UTF-8\\\\n\"/"
 
