@@ -61,7 +61,7 @@ while read package; do
 	# matching does not match the wrong tarball.
 	# See pacman and pacman-contrib for an example.
 	rm -rf tmp
-done < packages.txt
+done < packages.bin.txt
 rm "$page" "$cpio_archive"
 
 # Download HTML page for noarch
@@ -105,7 +105,7 @@ while read package; do
 	# matching does not match the wrong tarball.
 	# See pacman and pacman-contrib for an example.
 	rm -rf tmp
-done < packages.txt
+done < packages.noarch.txt
 rm "$page" "$cpio_archive"
 
 	# Special case for grub2-mknetdir.1. This file contains an unprintable
